@@ -2,7 +2,6 @@ from pathlib import Path
 import sys
 import typer
 
-from snowcli import config, utils
 from snowcli.config import AppConfig
 from snowcli.snowsql_config import SnowsqlConfig
 from snowcli.cli import connection
@@ -74,6 +73,12 @@ def configure(environment: str = typer.Option('dev', '-e', '--environment',
     cfg.save()
     print(f"Wrote environment {environment} to {cfg.path}")
 
+@app.callback()
+def default() -> None:
+    """
+    SnowCLI - A CLI for Snowflake                    
+    """
+
 app.add_typer(function.app, name="function")
 app.add_typer(procedure.app, name="procedure")
 app.add_typer(streamlit.app, name="streamlit")
@@ -82,3 +87,6 @@ app.add_typer(warehouse.app, name="warehouse")
 
 if __name__ == '__main__':
     app()
+
+if getattr(sys, 'frozen', False):
+    app(sys.argv[1:])
\ No newline at end of file
