@@ -1,5 +1,3 @@
-import configparser
-import os
 from pathlib import Path
 
 import click
